@@ -1352,7 +1352,7 @@ class SQLCli(object):
         if m_Parameters[0] == 'save':
             yield None, None, None, None, "Session saved Successful."
         if m_Parameters[0] == 'restore':
-            self.DoSQL("set JDBCURL " + self.db_url)
+            self.SQLOptions.set("CONNURL", self.db_url)
             yield None, None, None, None, "Session restored Successful."
         return
 
